@@ -28,6 +28,9 @@ __all__ = [
 def convert_court_to_id(trial_court) -> str:
   if isinstance(trial_court, str):
     return trial_court
+  if isinstance(trial_court, dict):
+    return trial_court['code']
+  # TODO(brycew): not sure what input this would be
   return str(trial_court.name)
 
 def choices_and_map(codes_list:List, display:str=None, backing:str=None) -> Tuple[List[Any], Dict]:
@@ -350,11 +353,12 @@ def get_tyler_roles(proxy_conn, login_data) -> Tuple[bool, bool]:
     return False, False
 
   user_details = proxy_conn.get_user(login_data.get('TYLER-ID', login_data.get('TYLER_ID')))
+  firm_details = proxy_conn.get_firm()
   if not user_details.data:
     return False, False
 
   is_admin = lambda role: role.get('roleName') == 'FIRM_ADMIN'
-  logged_in_user_is_admin = any(filter(is_admin, user_details.data.get('role')))
+  logged_in_user_is_admin = any(filter(is_admin, user_details.data.get('role'))) and not firm_details.data.get('isIndividual', False)
   logged_in_user_is_global_admin = logged_in_user_is_admin and \
       user_details.data.get('email') in get_config('efile proxy').get('global server admins',[])
   return logged_in_user_is_admin, logged_in_user_is_global_admin
