@@ -4,7 +4,7 @@ import json
 import logging
 import isodate
 from datetime import datetime
-from typing import Union, List, Dict
+from typing import Optional, Union, List, Dict
 import http.client as http_client
 
 from urllib.parse import urlencode
@@ -44,7 +44,7 @@ def _give_data_url(bundle: ALDocumentBundle):
   for doc in bundle:
     doc.proxy_enabled = doc.always_enabled or doc.enabled
     if doc.proxy_enabled:
-      doc.data_url = doc.as_pdf().url_for(temporary=True)
+      doc.data_url = doc.as_pdf().url_for(external=True, temporary=True)
       doc.page_count = doc.as_pdf().num_pages()
     if hasattr(doc, 'enabled'):
       del doc.enabled
@@ -53,18 +53,15 @@ def _get_all_vars(bundle: ALDocumentBundle):
   """Strips out some extra big variables that we don't need to serialize and send across the network"""
   _give_data_url(bundle)
   all_vars_dict = all_variables()
-  all_vars_dict.pop('trial_court_resp', None)
-  all_vars_dict.pop('x', None)
-  all_vars_dict.pop('trial_court_options', None)
-  all_vars_dict.pop('found_case', None)
-  all_vars_dict.pop('selected_exisiting_case', None)
-  all_vars_dict.pop('filing_type_options', None)
-  all_vars_dict.pop('filing_type_map', None)
-  all_vars_dict.pop('party_type_options', None)
+  vars_to_pop = ['trial_court_resp', 'x', 'trial_court_options', 'found_case', 'selected_existing_case', 
+      'filing_type_options', 'filing_type_map', 'party_type_options',
+      'available_efile_courts', 'case_category_map']
+  for var in vars_to_pop:
+    all_vars_dict.pop(var, None)
   return json.dumps(all_vars_dict)
 
 class ProxyConnection:
-  def __init__(self, url:str=None, api_key:str=None, credentials_code_block:str='tyler_login'):
+  def __init__(self, url:str=None, api_key:str=None, credentials_code_block:str='tyler_login', *, default_jurisdiction:str=None):
     temp_efile_config = get_config('efile proxy', {})
     if url is None:
       url = temp_efile_config.get('url', '')
@@ -77,6 +74,8 @@ class ProxyConnection:
     self.api_key = api_key
     self.proxy_client = requests.Session()
     self.active_token = None
+    print(f"setting default jurisdiction to {default_jurisdiction}")
+    self.default_jurisdiction = default_jurisdiction
     self.proxy_client.headers = {
       'Content-type': 'application/json',
       'Accept': 'application/json',
@@ -131,8 +130,20 @@ class ProxyConnection:
     except:
       return ApiResponse(resp.status_code, resp.text, None)
 
-  def authenticate_user(self, tyler_email:str=None, tyler_password:str=None, jeffnet_key:str=None):
+  def full_url(self, endpoint:str, jurisdiction:str=None):
+    if jurisdiction is None:
+      jurisdiction = self.default_jurisdiction
+    if endpoint.startswith('authenticate_user') or endpoint.startswith('messages'):
+      return self.base_url + endpoint
+    return self.base_url + f'/jurisdictions/{jurisdiction}/{endpoint}'
+
+  def authenticate_user(self, tyler_email:str=None, tyler_password:str=None, jeffnet_key:str=None, *, jurisdiction:str=None):
     temp_efile_config = get_config('efile proxy', {})
+    print(f"jurisdiction: {jurisdiction}")
+    if jurisdiction is None:
+      print(f"default jurisdiction: {self.default_jurisdiction}")
+      jurisdiction = self.default_jurisdiction
+    print(f"jurisdiction post default: {jurisdiction}")
     if tyler_email is None:
       tyler_email = temp_efile_config.get('tyler email')
     if tyler_password is None:
@@ -144,9 +155,9 @@ class ProxyConnection:
     if jeffnet_key:
       auth_obj['jeffnet'] = {'key': jeffnet_key}
     if tyler_email and tyler_password:
-      auth_obj['tyler'] = {'username': tyler_email, 'password': tyler_password}
+      auth_obj[f'tyler-{jurisdiction}'] = {'username': tyler_email, 'password': tyler_password}
     try:
-      resp = self.proxy_client.post(self.base_url + 'adminusers/authenticate',
+      resp = self.proxy_client.post(self.base_url + 'authenticate',
         data=json.dumps(auth_obj))
       if resp.status_code == requests.codes.ok:
         all_tokens = resp.json().get('tokens', {})
@@ -191,14 +202,14 @@ class ProxyConnection:
     if registration_type != 'FIRM_ADMIN_NEW_MEMBER':
       reg_obj['password'] = password
 
-    send = lambda: self.proxy_client.put(self.base_url + 'adminusers/users', data=json.dumps(reg_obj))
+    send = lambda: self.proxy_client.put(self.full_url("adminusers/users"), data=json.dumps(reg_obj))
     return self._call_proxy(send)
 
   def get_password_rules(self):
     """
     Password rules are stored in the global court, id 1.
     """
-    send = lambda: self.proxy_client.get(self.base_url + "/codes/courts/1/datafields/GlobalPassword")
+    send = lambda: self.proxy_client.get(self.full_url("codes/courts/1/datafields/GlobalPassword"))
     return self._call_proxy(send)
 
   def is_valid_password(self, password):
@@ -213,7 +224,7 @@ class ProxyConnection:
   # Managing Firm Users
 
   def get_user_list(self):
-    send = lambda: self.proxy_client.get(self.base_url + 'adminusers/users')
+    send = lambda: self.proxy_client.get(self.full_url('adminusers/users'))
     return self._call_proxy(send)
 
   def get_users(self):
@@ -221,173 +232,173 @@ class ProxyConnection:
 
   def get_user(self, id:str=None):
     if id is None:
-      send = lambda: self.proxy_client.get(self.base_url + f'adminusers/user')
+      send = lambda: self.proxy_client.get(self.full_url('adminusers/user'))
     else:
-      send = lambda: self.proxy_client.get(self.base_url + f'adminusers/users/{id}')
+      send = lambda: self.proxy_client.get(self.full_url(f'adminusers/users/{id}'))
     return self._call_proxy(send)
 
   def get_user_roles(self, id:str):
-    send = lambda: self.proxy_client.get(self.base_url + f'adminusers/users/{id}/roles')
+    send = lambda: self.proxy_client.get(self.full_url(f'adminusers/users/{id}/roles'))
     return self._call_proxy(send)
 
   def add_user_roles(self, id:str, roles:List[dict]):
-    send = lambda: self.proxy_client.post(self.base_url + f'adminusers/users/{id}/roles',
+    send = lambda: self.proxy_client.post(self.full_url(f'adminusers/users/{id}/roles'),
       data=json.dumps(roles))
     return self._call_proxy(send)
 
   def remove_user_roles(self, id:str, roles:List[dict]):
-    send = lambda: self.proxy_client.delete(self.base_url + f'adminusers/users/{id}/roles',
+    send = lambda: self.proxy_client.delete(self.full_url(f'adminusers/users/{id}/roles'),
         data=json.dumps(roles))
     return self._call_proxy(send)
 
   def change_password(self, id:str, email:str, new_password:str):
-    send = lambda: self.proxy_client.post(self.base_url + f'adminusers/users/{id}/password',
+    send = lambda: self.proxy_client.post(self.full_url(f'adminusers/users/{id}/password'),
         data=json.dumps({'email': email, 'newPassword': new_password}))
     return self._call_proxy(send)
 
   def self_change_password(self, current_password:str, new_password:str):
-    send = lambda: self.proxy_client.post(self.base_url + f'adminusers/user/password',
+    send = lambda: self.proxy_client.post(self.full_url('adminusers/user/password'),
         data=json.dumps({'currentPassword': current_password, 'newPassword': new_password}))
     return self._call_proxy(send)
 
   def self_resend_activation_email(self, email: str):
-    send = lambda: self.proxy_client.post(self.base_url + 'adminusers/user/resend-activation-email',
+    send = lambda: self.proxy_client.post(self.full_url('adminusers/user/resend-activation-email'),
         data=email)
     return self._call_proxy(send)
 
   def resend_activation_email(self, id:str):
-    send = lambda: self.proxy_client.post(self.base_url + f'adminusers/users/{id}/resend-activation-email')
+    send = lambda: self.proxy_client.post(self.full_url(f'adminusers/users/{id}/resend-activation-email'))
     return self._call_proxy(send)
 
   def update_notification_preferences(self, notif_preferences:List[dict]):
-    send = lambda: self.proxy_client.patch(self.base_url + f'adminusers/user/notification-preferences',
+    send = lambda: self.proxy_client.patch(self.full_url(f'adminusers/user/notification-preferences'),
         data=json.dumps(notif_preferences))
     return self._call_proxy(send)
 
   def get_notification_preferences(self):
-    send = lambda: self.proxy_client.get(self.base_url + 'adminusers/user/notification-preferences')
+    send = lambda: self.proxy_client.get(self.full_url('adminusers/user/notification-preferences'))
     return self._call_proxy(send)
 
   def get_notification_options(self):
     """AKA NotificationPreferencesList"""
-    send = lambda: self.proxy_client.get(self.base_url + 'adminusers/notification-options')
+    send = lambda: self.proxy_client.get(self.full_url('adminusers/notification-options'))
     return self._call_proxy(send)
 
   def self_update_user(self, email:str=None, first_name:str=None, middle_name:str=None, last_name:str=None):
     updated_user = {'email': email, 'firstName': first_name, 'middleName': middle_name, 'lastName': last_name}
-    send = lambda: self.proxy_client.patch(self.base_url + f'adminusers/user', data=json.dumps(updated_user))
+    send = lambda: self.proxy_client.patch(self.full_url('adminusers/user'), data=json.dumps(updated_user))
     return self._call_proxy(send)
 
   def update_user(self, id:str, email:str=None, first_name:str=None, middle_name:str=None, last_name:str=None):
     updated_user = {'email': email, 'firstName': first_name, 'middleName': middle_name, 'lastName': last_name}
-    send = lambda: self.proxy_client.patch(self.base_url + f'adminusers/users/{id}', data=json.dumps(updated_user))
+    send = lambda: self.proxy_client.patch(self.full_url(f'adminusers/users/{id}'), data=json.dumps(updated_user))
     return self._call_proxy(send) 
 
   def remove_user(self, id:str):
     #if id is None:
     #    id = self.authed_user_id
-    send = lambda: self.proxy_client.delete(self.base_url + f'adminusers/users/{id}')
+    send = lambda: self.proxy_client.delete(self.full_url(f'adminusers/users/{id}'))
     return self._call_proxy(send)
 
   # TODO(brycew): not tested
   def reset_user_password(self, email:str):
-    send = lambda: self.proxy_client.post(self.base_url + 'adminusers/user/password/reset', data=email)
-    return self._call_proxy(send)
-
-  def get_password_question(self, email:str):
-    send = lambda: self.proxy_client.get(self.base_url + 'adminusers/user/password-question', data=email)
+    send = lambda: self.proxy_client.post(self.full_url('adminusers/user/password/reset'), data=email)
     return self._call_proxy(send)
 
   # Managing a Firm
   def get_firm(self):
-    send = lambda: self.proxy_client.get(self.base_url + 'firmattorneyservice/firm')
+    send = lambda: self.proxy_client.get(self.full_url('firmattorneyservice/firm'))
     return self._call_proxy(send)
 
   def update_firm(self, firm:Person):
     # firm is stateful
     update = serialize_person(firm)
 
-    send = lambda: self.proxy_client.patch(self.base_url + f'firmattorneyservice/firm', data=json.dumps(update))
+    send = lambda: self.proxy_client.patch(self.full_url('firmattorneyservice/firm'), data=json.dumps(update))
     return self._call_proxy(send)
 
   # Managing Attorneys
   def get_attorney_list(self):
-    send = lambda: self.proxy_client.get(self.base_url + f'firmattorneyservice/attorneys')
+    send = lambda: self.proxy_client.get(self.full_url('firmattorneyservice/attorneys'))
     return self._call_proxy(send)
 
   def get_attorney(self, attorney_id):
-    send = lambda: self.proxy_client.get(self.base_url + f'firmattorneyservice/attorneys/{attorney_id}')
+    send = lambda: self.proxy_client.get(self.full_url(f'firmattorneyservice/attorneys/{attorney_id}'))
     return self._call_proxy(send)
 
   def update_attorney(self, attorney_id, bar_number:str=None,
       first_name:str=None, middle_name:str=None, last_name:str=None):
-    send = lambda: self.proxy_client.patch(self.base_url + f'firmattorneyservice/attorneys/{attorney_id}', 
+    send = lambda: self.proxy_client.patch(self.full_url(f'firmattorneyservice/attorneys/{attorney_id}'),
         data=json.dumps({'barNumber': bar_number, 'firstName': first_name, 'middleName': middle_name, 'lastName': last_name}))
     return self._call_proxy(send) 
 
   def create_attorney(self, bar_number:str, first_name:str, middle_name:str=None, last_name:str=None):
-    send = lambda: self.proxy_client.post(self.base_url + f'firmattorneyservice/attorneys', 
+    send = lambda: self.proxy_client.post(self.full_url('firmattorneyservice/attorneys'), 
         data=json.dumps({'barNumber': bar_number, 'firstName': first_name, 'middleName': middle_name, 'lastName': last_name}))
     return self._call_proxy(send)
 
   def remove_attorney(self, attorney_id):
-    send = lambda: self.proxy_client.delete(self.base_url + f'firmattorneyservice/attorneys/{attorney_id}')
+    send = lambda: self.proxy_client.delete(self.full_url(f'firmattorneyservice/attorneys/{attorney_id}'))
     return self._call_proxy(send)
 
   # Managing Payment Accounts
   def get_payment_account_type_list(self):
-    send = lambda: self.proxy_client.get(self.base_url + f'payments/types')
+    send = lambda: self.proxy_client.get(self.full_url('payments/types'))
     return self._call_proxy(send)
 
-  def get_payment_account_list(self):
-    send = lambda: self.proxy_client.get(self.base_url + f'payments/payment-accounts')
+  def get_payment_account_list(self, court_id:Optional[str]=None):
+    if not court_id:
+      send = lambda: self.proxy_client.get(self.full_url('payments/payment-accounts'))
+    else:
+      params = {'court_id': court_id}
+      send = lambda: self.proxy_client.get(self.full_url('payments/payment-accounts'), params=params)
     return self._call_proxy(send) 
 
   def get_payment_account(self, payment_account_id):
-    send = lambda: self.proxy_client.get(self.base_url + f'payments/payment-accounts/{payment_account_id}')
+    send = lambda: self.proxy_client.get(self.full_url(f'payments/payment-accounts/{payment_account_id}'))
     return self._call_proxy(send)
 
   def update_payment_account(self, payment_account_id, account_name:str=None, active:bool=True):
-    send = lambda: self.proxy_client.patch(self.base_url + f'payments/payment-accounts/{payment_account_id}', 
+    send = lambda: self.proxy_client.patch(self.full_url(f'payments/payment-accounts/{payment_account_id}'), 
         data=json.dumps({'account_name': account_name, 'active': active}))
     return self._call_proxy(send) 
 
   def remove_payment_account(self, payment_account_id):
-    send = lambda: self.proxy_client.delete(self.base_url + f'payments/payment-accounts/{payment_account_id}')
+    send = lambda: self.proxy_client.delete(self.full_url(f'payments/payment-accounts/{payment_account_id}'))
     return self._call_proxy(send) 
 
   # Both types of accounts
   def create_waiver_account(self, account_name:str, is_global:bool):
-    url = self.base_url + f'payments/global-accounts' if is_global else self.base_url + f'payments/payment-accounts'
+    url = self.full_url('payments/global-accounts' if is_global else 'payments/payment-accounts')
     send = lambda: self.proxy_client.post(url, data=account_name)
     return self._call_proxy(send)
 
   # Global Payment Accounts
   def get_global_payment_account_list(self):
-    send = lambda: self.proxy_client.get(self.base_url + f'payments/global-accounts')
+    send = lambda: self.proxy_client.get(self.full_url('payments/global-accounts'))
     return self._call_proxy(send) 
 
   def get_global_payment_account(self, global_payment_account_id):
-    send = lambda: self.proxy_client.get(self.base_url + f'payments/global-accounts/{global_payment_account_id}')
+    send = lambda: self.proxy_client.get(self.full_url(f'payments/global-accounts/{global_payment_account_id}'))
     return self._call_proxy(send) 
 
   def update_global_payment_account(self, global_payment_account_id, account_name:str=None, active:bool=True):
-    send = lambda: self.proxy_client.patch(self.base_url + f'payments/global-accounts/{global_payment_account_id}', 
+    send = lambda: self.proxy_client.patch(self.full_url(f'payments/global-accounts/{global_payment_account_id}'),
         data=json.dumps({'account_name': account_name, 'active': active}))
     return self._call_proxy(send) 
 
   def remove_global_payment_account(self, global_payment_account_id):
-    send = lambda: self.proxy_client.delete(self.base_url + f'payments/global-accounts/{global_payment_account_id}')
+    send = lambda: self.proxy_client.delete(self.full_url(f'payments/global-accounts/{global_payment_account_id}'))
     return self._call_proxy(send) 
 
   # Managing Service Contacts
   # Service contacts are part of the `firm` hierarchy
   def get_service_contact_list(self):
-    send = lambda: self.proxy_client.get(self.base_url + f'firmattorneyservice/service-contacts')
+    send = lambda: self.proxy_client.get(self.full_url(f'firmattorneyservice/service-contacts'))
     return self._call_proxy(send)
 
   def get_service_contact(self, service_contact_id):
-    send = lambda: self.proxy_client.get(self.base_url + f'firmattorneyservice/service-contacts/{service_contact_id}')
+    send = lambda: self.proxy_client.get(self.full_url(f'firmattorneyservice/service-contacts/{service_contact_id}'))
     return self._call_proxy(send)
 
   def update_service_contact(self, service_contact_id, service_contact:Individual, is_public:bool=None, is_in_master_list:bool=None, admin_copy:str=None):
@@ -395,48 +406,48 @@ class ProxyConnection:
     service_contact_dict['isPublic'] = is_public
     service_contact_dict['isInFirmMasterList'] = is_in_master_list
     service_contact_dict['administrativeCopy'] = admin_copy
-    send = lambda: self.proxy_client.patch(self.base_url + f'firmattorneyservice/service-contacts/{service_contact_id}', 
+    send = lambda: self.proxy_client.patch(self.full_url(f'firmattorneyservice/service-contacts/{service_contact_id}'),
         data=json.dumps(service_contact_dict))
     return self._call_proxy(send)
 
-  def create_service_contact(self, service_contact:Individual, is_public:bool, is_in_master_list:bool, admin_copy:str=None):     
+  def create_service_contact(self, service_contact:Individual, is_public:bool, is_in_master_list:bool, admin_copy:str=None):
     service_contact_dict = serialize_person(service_contact)
     service_contact_dict['isPublic'] = is_public
     service_contact_dict['isInFirmMaster'] = is_in_master_list
     service_contact_dict['administrativeCopy'] = admin_copy
-    send = lambda: self.proxy_client.post(self.base_url + f'firmattorneyservice/service-contacts', 
+    send = lambda: self.proxy_client.post(self.full_url('firmattorneyservice/service-contacts'), 
         data=json.dumps(service_contact_dict))
     return self._call_proxy(send)
 
   def remove_service_contact(self, service_contact_id):
-    send = lambda: self.proxy_client.delete(self.base_url + f'firmattorneyservice/service-contacts/{service_contact_id}')
+    send = lambda: self.proxy_client.delete(self.full_url(f'firmattorneyservice/service-contacts/{service_contact_id}'))
     return self._call_proxy(send)
 
   def get_public_service_contacts(self, first_name:str=None, middle_name:str=None, last_name:str=None, email:str=None):
-    send = lambda: self.proxy_client.get(self.base_url + f'firmattorneyservice/service-contacts/public',
+    send = lambda: self.proxy_client.get(self.full_url(f'firmattorneyservice/service-contacts/public'),
         data=json.dumps({'firstName': first_name, 'middleName': middle_name, 'lastName': last_name, 'email': email}))
     return self._call_proxy(send)
 
   # Using Service Contacts
   def attach_service_contact(self, service_contact_id:str, case_id:str, case_party_id:str=None):
-    send = lambda: self.proxy_client.put(self.base_url + f'firmattorneyservice/service-contacts/{service_contact_id}/cases',
+    send = lambda: self.proxy_client.put(self.full_url(f'firmattorneyservice/service-contacts/{service_contact_id}/cases'),
         data=json.dumps({'caseId': case_id, 'casepartyId': case_party_id}))
     return self._call_proxy(send)
 
   def detach_service_contact(self, service_contact_id:str, case_id:str, case_party_id:str=None):
-    url = self.base_url + f'firmattorneyservice/service-contacts/{service_contact_id}/cases/{case_id}'
+    url = self.full_url(f'firmattorneyservice/service-contacts/{service_contact_id}/cases/{case_id}')
     if case_party_id is not None:
       url += urlencode({'case_party_id': case_party_id})
     send = lambda: self.proxy_client.delete(url)
     return self._call_proxy(send)
   
   def get_attached_cases(self, court_id:str, service_contact_id:str):
-    url = self.base_url + f'cases/courts/{court_id}/service-contacts/{service_contact_id}/cases'
+    url = self.full_url(f'cases/courts/{court_id}/service-contacts/{service_contact_id}/cases')
     send = lambda: self.proxy_client.get(url)
     return self._call_proxy(send)
 
   def get_public_list(self):
-    send = lambda: self.proxy_client.get(self.base_url + f'firmattorneyservice/service-contacts/public')
+    send = lambda: self.proxy_client.get(self.full_url('firmattorneyservice/service-contacts/public'))
     return self._call_proxy(send)
   
   def get_courts(self, fileable_only:bool=False, with_names:bool=False):
@@ -444,74 +455,74 @@ class ProxyConnection:
       'fileable_only': fileable_only,
       'with_names': with_names
     }
-    send = lambda: self.proxy_client.get(self.base_url + f'codes/courts', params=params)
+    send = lambda: self.proxy_client.get(self.full_url('codes/courts'), params=params)
     return self._call_proxy(send)
   
   def get_court(self, court_id:str):
-    send = lambda: self.proxy_client.get(self.base_url + f'codes/courts/{court_id}/codes')
+    send = lambda: self.proxy_client.get(self.full_url(f'codes/courts/{court_id}/codes'))
     return self._call_proxy(send)
 
-  def get_court_list(self, jurisdiction:str):
-    send = lambda: self.proxy_client.get(self.base_url + f'filingreview/jurisdictions/{jurisdiction}/courts')
+  def get_court_list(self):
+    send = lambda: self.proxy_client.get(self.full_url(f'filingreview/courts'))
     return self._call_proxy(send)
 
-  def get_filing_list(self, jurisdiction:str, court_id:str, user_id:str=None, start_date:DADateTime=None, end_date:DADateTime=None):
+  def get_filing_list(self, court_id:str, user_id:str=None, start_date:DADateTime=None, end_date:DADateTime=None):
     params = {
       "user_id": user_id,
       "start_date": as_datetime(start_date).format("yyyy-MM-dd") if start_date else None,
       "end_date": as_datetime(end_date).format("yyyy-MM-dd") if end_date else None
     }
-    send = lambda: self.proxy_client.get(self.base_url + f'filingreview/jurisdictions/{jurisdiction}/courts/{court_id}/filings', params=params)
+    send = lambda: self.proxy_client.get(self.full_url(f'filingreview/courts/{court_id}/filings'), params=params)
     return self._call_proxy(send) 
 
-  def get_filing(self, jurisdiction:str, court_id:str, filing_id:str):
-    send = lambda: self.proxy_client.get(self.base_url + f'filingreview/jurisdictions/{jurisdiction}/courts/{court_id}/filings/{filing_id}')
+  def get_filing(self, court_id:str, filing_id:str):
+    send = lambda: self.proxy_client.get(self.full_url(f'filingreview/courts/{court_id}/filings/{filing_id}'))
     return self._call_proxy(send) 
 
-  def get_policy(self, jurisdiction:str, court_id:str):
-    send = lambda: self.proxy_client.get(self.base_url + f'filingreview/jurisdictions/{jurisdiction}/courts/{court_id}/policy')
+  def get_policy(self, court_id:str):
+    send = lambda: self.proxy_client.get(self.full_url(f'filingreview/courts/{court_id}/policy'))
     return self._call_proxy(send)
 
-  def get_filing_status(self, jurisdiction:str, court_id:str, filing_id:str):
-    send = lambda: self.proxy_client.get(self.base_url + f'filingreview/jurisdictions/{jurisdiction}/courts/{court_id}/filings/{filing_id}/status')
+  def get_filing_status(self, court_id:str, filing_id:str):
+    send = lambda: self.proxy_client.get(self.full_url(f'filingreview/courts/{court_id}/filings/{filing_id}/status'))
     return self._call_proxy(send)
 
-  def cancel_filing_status(self, jurisdiction:str, court_id:str, filing_id:str):
-    send = lambda: self.proxy_client.delete(self.base_url + f'filingreview/jurisdictions/{jurisdiction}/courts/{court_id}/filings/{filing_id}')
+  def cancel_filing_status(self, court_id:str, filing_id:str):
+    send = lambda: self.proxy_client.delete(self.full_url(f'filingreview/courts/{court_id}/filings/{filing_id}'))
     return self._call_proxy(send) 
 
-  def check_filing(self, jurisdiction:str, court_id:str, court_bundle:ALDocumentBundle=None):
+  def check_filing(self, court_id:str, court_bundle:ALDocumentBundle=None):
     all_vars = _get_all_vars(court_bundle) 
-    send = lambda: self.proxy_client.get(self.base_url + f'filingreview/jurisdictions/{jurisdiction}/courts/{court_id}/filing/check', data=all_vars)
+    send = lambda: self.proxy_client.get(self.full_url(f'filingreview/courts/{court_id}/filing/check'), data=all_vars)
     return self._call_proxy(send)
 
-  def file_for_review(self, jurisdiction: str, court_id:str, court_bundle:ALDocumentBundle=None):
+  def file_for_review(self, court_id:str, court_bundle:ALDocumentBundle=None):
     all_vars = _get_all_vars(court_bundle) 
-    send = lambda: self.proxy_client.post(self.base_url + f'filingreview/jurisdictions/{jurisdiction}/courts/{court_id}/filings',
+    send = lambda: self.proxy_client.post(self.full_url(f'filingreview/courts/{court_id}/filings'),
           data=all_vars)
     return self._call_proxy(send)
 
-  def get_service_types(self, jurisdiction:str, court_id:str, court_bundle:ALDocumentBundle=None):
+  def get_service_types(self, court_id:str, court_bundle:ALDocumentBundle=None):
     """Checks the court info: if it has conditional service types, call a special API with all filing info so far to get service types"""
     court_info = self.get_court(court_id)
     if court_info.data.get('hasconditionalservicetypes'):
       all_vars = _get_all_vars(court_bundle) 
-      send = lambda: self.proxy_client.get(self.base_url + f'filingreview/jurisdictions/{jurisdiction}/courts/{court_id}/filing/servicetypes',
+      send = lambda: self.proxy_client.get(self.full_url(f'filingreview/courts/{court_id}/filing/servicetypes'),
         data=all_vars)
       return self._call_proxy(send)
     else:
       return self.get_service_type_codes(court_id)
       
   # TODO(brycew): rethink service API
-  #def serve(self, jurisdiction:str, court_id:str, court_bundle:ALDocumentBundle=None):
+  #def serve(self, court_id:str, court_bundle:ALDocumentBundle=None):
   #  all_vars = _get_all_vars(court_bundle) 
-  #  send = lambda: self.proxy_client.post(self.base_url + f'filingreview/jurisdictions/{jurisdiction}/courts/{court_id}/filing/serve',
+  #  send = lambda: self.proxy_client.post(self.full_url(f'filingreview/courts/{court_id}/filing/serve',
   #                                        data=all_vars)
   #  return self._call_proxy(send)
   
-  def calculate_filing_fees(self, jurisdiction:str, court_id:str, court_bundle:ALDocumentBundle=None):
+  def calculate_filing_fees(self, court_id:str, court_bundle:ALDocumentBundle=None):
     all_vars = _get_all_vars(court_bundle)
-    send = lambda: self.proxy_client.post(self.base_url + f'filingreview/jurisdictions/{jurisdiction}/courts/{court_id}/filing/fees',
+    send = lambda: self.proxy_client.post(self.full_url(f'filingreview/courts/{court_id}/filing/fees'),
           data=all_vars)
     return self._call_proxy(send)
 
@@ -519,7 +530,7 @@ class ProxyConnection:
     _give_data_url(court_bundle)
     all_vars_obj = all_variables()
     all_vars_obj['return_date'] = req_return_date.isoformat()
-    send = lambda: self.proxy_client.post(self.base_url + f'scheduling/courts/{court_id}/return_date', data=json.dumps(all_vars_obj))
+    send = lambda: self.proxy_client.post(self.full_url(f'scheduling/courts/{court_id}/return_date'), data=json.dumps(all_vars_obj))
     return self._call_proxy(send)
 
   def reserve_court_date(self, court_id:str, doc_id:str,
@@ -532,7 +543,7 @@ class ProxyConnection:
     log(f'before: {range_before}')
     if estimated_duration is not None:
       estimated_duration = int(estimated_duration) * 60 * 60
-    send = lambda: self.proxy_client.post(self.base_url + f'scheduling/courts/{court_id}/reserve_date',
+    send = lambda: self.proxy_client.post(self.full_url(f'scheduling/courts/{court_id}/reserve_date'),
         data=json.dumps({'doc_id': doc_id, 'estimated_duration': estimated_duration, 'range_after' : range_after, 'range_before': range_before}))
     return self._call_proxy(send)
   
@@ -545,7 +556,7 @@ class ProxyConnection:
       return self._get_cases(court_id, person_name=person.name.as_serializable(), docket_id=docket_id)
   
   def _get_cases(self, court_id:str, person_name:dict=None, business_name:str=None, docket_id:str=None) -> ApiResponse:
-    send = lambda: self.proxy_client.get(self.base_url + f'cases/courts/{court_id}/cases', 
+    send = lambda: self.proxy_client.get(self.full_url(f'cases/courts/{court_id}/cases'), 
         params={
           'first_name': person_name.get('first') if person_name is not None else None,
           'middle_name': person_name.get('middle') if person_name is not None else None,
@@ -555,25 +566,25 @@ class ProxyConnection:
     return self._call_proxy(send)
 
   def get_case(self, court_id:str, case_id:str):
-    send = lambda: self.proxy_client.get(self.base_url + f'cases/courts/{court_id}/cases/{case_id}')
+    send = lambda: self.proxy_client.get(self.full_url(f'cases/courts/{court_id}/cases/{case_id}'))
     return self._call_proxy(send)
 
   def get_document(self, court_id:str, case_id:str):
-    send = lambda: self.proxy_client.get(self.base_url + f'cases/courts/{court_id}/cases/{case_id}/documents')
+    send = lambda: self.proxy_client.get(self.full_url(f'cases/courts/{court_id}/cases/{case_id}/documents'))
     return self._call_proxy(send)
 
   def get_service_attach_case_list(self, court_id:str, service_contact_id:str):
-    send = lambda: self.proxy_client.get(self.base_url + f'cases/courts/{court_id}/service-contacts/{service_contact_id}/cases')
+    send = lambda: self.proxy_client.get(self.full_url(f'cases/courts/{court_id}/service-contacts/{service_contact_id}/cases'))
     return self._call_proxy(send)
 
   def get_service_information(self, court_id:str, case_tracking_id:str):
     send = lambda: self.proxy_client.get(
-        self.base_url + f'cases/courts/{court_id}/cases/{case_tracking_id}/service-information')
+        self.full_url(f'cases/courts/{court_id}/cases/{case_tracking_id}/service-information'))
     return self._call_proxy(send)
 
   def get_service_information_history(self, court_id:str, case_tracking_id:str):
     send = lambda: self.proxy_client.get(
-        self.base_url + f'cases/courts/{court_id}/cases/{case_tracking_id}/service-information-history')
+        self.full_url(f'cases/courts/{court_id}/cases/{case_tracking_id}/service-information-history'))
     return self._call_proxy(send)
   
   def get_case_categories(self, court_id:str, fileable_only:bool=False, timing:str=None):
@@ -581,7 +592,7 @@ class ProxyConnection:
       "fileable_only": fileable_only,
       "timing": timing 
     }
-    send = lambda: self.proxy_client.get(self.base_url + f'codes/courts/{court_id}/categories', params=params) 
+    send = lambda: self.proxy_client.get(self.full_url(f'codes/courts/{court_id}/categories'), params=params) 
     return self._call_proxy(send)
   
   def get_case_types(self, court_id:str, case_category:str, timing:str=None):
@@ -589,11 +600,11 @@ class ProxyConnection:
       'category_id': case_category,
       'timing': timing
     }
-    send = lambda: self.proxy_client.get(self.base_url + f'codes/courts/{court_id}/case_types', params=params) 
+    send = lambda: self.proxy_client.get(self.full_url(f'codes/courts/{court_id}/case_types'), params=params) 
     return self._call_proxy(send)
   
   def get_case_subtypes(self, court_id:str, case_type:str):
-    send = lambda: self.proxy_client.get(self.base_url + f'codes/courts/{court_id}/case_types/{case_type}/case_subtypes')
+    send = lambda: self.proxy_client.get(self.full_url(f'codes/courts/{court_id}/case_types/{case_type}/case_subtypes'))
     return self._call_proxy(send)
   
   def get_filing_types(self, court_id:str, case_category:str, case_type:str, initial:bool):
@@ -602,43 +613,43 @@ class ProxyConnection:
       'type_id': case_type,
       'initial': initial
     }
-    send = lambda: self.proxy_client.get(self.base_url + f'codes/courts/{court_id}/filing_types', params=params)
+    send = lambda: self.proxy_client.get(self.full_url(f'codes/courts/{court_id}/filing_types'), params=params)
     return self._call_proxy(send)
   
   def get_service_type_codes(self, court_id:str): 
-    send = lambda: self.proxy_client.get(self.base_url + f'codes/courts/{court_id}/service_types')
+    send = lambda: self.proxy_client.get(self.full_url(f'codes/courts/{court_id}/service_types'))
     return self._call_proxy(send)
   
   def get_party_types(self, court_id:str, case_type_id:str):
-    send = lambda: self.proxy_client.get(self.base_url + f'codes/courts/{court_id}/case_types/{case_type_id}/party_types')
+    send = lambda: self.proxy_client.get(self.full_url(f'codes/courts/{court_id}/case_types/{case_type_id}/party_types'))
     return self._call_proxy(send)
   
   def get_document_types(self, court_id:str, filing_type:str):
-    send = lambda: self.proxy_client.get(self.base_url + f'codes/courts/{court_id}/filing_codes/{filing_type}/document_types')
+    send = lambda: self.proxy_client.get(self.full_url(f'codes/courts/{court_id}/filing_types/{filing_type}/document_types'))
     return self._call_proxy(send)
   
   def get_motion_types(self, court_id:str, filing_type:str):
-    send = lambda: self.proxy_client.get(self.base_url + f'codes/courts/{court_id}/filing_codes/{filing_type}/motion_types')
+    send = lambda: self.proxy_client.get(self.full_url(f'codes/courts/{court_id}/filing_types/{filing_type}/motion_types'))
     return self._call_proxy(send)
   
   def get_filing_components(self, court_id:str, filing_type:str):
-    send = lambda: self.proxy_client.get(self.base_url + f'codes/courts/{court_id}/filing_codes/{filing_type}/filing_components')
+    send = lambda: self.proxy_client.get(self.full_url(f'codes/courts/{court_id}/filing_types/{filing_type}/filing_components'))
     return self._call_proxy(send)
   
   def get_optional_services(self, court_id:str, filing_type:str):
-    send = lambda: self.proxy_client.get(self.base_url + f'codes/courts/{court_id}/filing_codes/{filing_type}/optional_services')
+    send = lambda: self.proxy_client.get(self.full_url(f'codes/courts/{court_id}/filing_types/{filing_type}/optional_services'))
     return self._call_proxy(send)
   
   def get_cross_references(self, court_id:str, case_type:str):
-    send = lambda: self.proxy_client.get(self.base_url + f'codes/courts/{court_id}/casetypes/{case_type}/cross_references')
+    send = lambda: self.proxy_client.get(self.full_url(f'codes/courts/{court_id}/casetypes/{case_type}/cross_references'))
     return self._call_proxy(send)
 
   def get_datafield(self, court_id:str, field_name:str):
-    send = lambda: self.proxy_client.get(self.base_url + f'codes/courts/{court_id}/datafields/{field_name}')
+    send = lambda: self.proxy_client.get(self.full_url(f'codes/courts/{court_id}/datafields/{field_name}'))
     return self._call_proxy(send)
 
   def get_disclaimers(self, court_id:str):
-    send = lambda: self.proxy_client.get(self.base_url + f'codes/courts/{court_id}/disclaimer_requirements')
+    send = lambda: self.proxy_client.get(self.full_url(f'codes/courts/{court_id}/disclaimer_requirements'))
     return self._call_proxy(send)
 
 
